@@ -151,14 +151,15 @@ def make_upload_header(token, org_id):
 	return {
 		'Authorization': f'Zoho-oauthtoken {token.access}',
 		'feature': 'bulk-write',
-		'X-CRM-ORG': org_id
+		'X-CRM-ORG': org_id,
+		'Content-Type': 'application/zip'
 
 	}
 		#'Content-Type': "multipart/form-data"
 	#}
 
 def upload_csv(token, org_id, module, filename):
-	url = "https://content.zohoapis.com/crm/v2.1/upload"
+	url = "https://content.zohoapis.com/crm/3/upload"
 	headers = make_upload_header(token, org_id)
 	with open(filename, 'rb') as upload_file:
 		request_body = {'file': upload_file}
